@@ -9,9 +9,6 @@ summary: >
 
 * [Batch Normalization](batch_norm/index.html)
 * [Layer Normalization](layer_norm/index.html)
-
-*TODO*
-
-* Instance Normalization
-* Group Normalization
-"""
\ No newline at end of file
+* [Instance Normalization](instance_norm/index.html)
+* [Group Normalization](group_norm/index.html)
+"""
